@@ -44,7 +44,7 @@ use fields qw(
               );
 
 use vars qw( %FIELDS $AUTOLOAD $VERSION );
-our $VERSION = '1.4';
+our $VERSION = '1.6';
 
 =head2 new()
 
@@ -546,7 +546,7 @@ __END__
 
 =head1 AUTHOR
 
-Mark Wong <markw@osdl.org>
+Mark Wong <markwkm@gmail.com>
  
 September 2006
 - response time sort to use numeric sort not ascii
@@ -555,7 +555,7 @@ Richard Kennedy EnterpriseDB
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006 Mark Wong & Open Source Development Labs, Inc.
+Copyright (C) 2006-2008 Mark Wong & Open Source Development Labs, Inc.
 All Rights Reserved.
 
 This script is free software; you can redistribute it and/or modify it
