@@ -35,7 +35,7 @@ use fields qw(
               );
 
 use vars qw( %FIELDS $AUTOLOAD $VERSION );
-our $VERSION = '1.4';
+our $VERSION = '1.6';
 
 =head2 new()
 
@@ -123,11 +123,11 @@ __END__
 
 =head1 AUTHOR
 
-Mark Wong <markw@osdl.org>
+Mark Wong <markwkm@gmail.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006 Mark Wong & Open Source Development Labs, Inc.
+Copyright (C) 2006-2008 Mark Wong & Open Source Development Labs, Inc.
 All Rights Reserved.
 
 This script is free software; you can redistribute it and/or modify it
